.. Secure Remote Password documentation master file, created by
   sphinx-quickstart on Fri Mar 25 10:20:52 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Secure Remote Password's documentation!
==================================================

Contents:

.. toctree::
   :maxdepth: 2

   srp.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

